#!/usr/bin/env python3

from datetime import date,datetime,timezone,timedelta
#import time
import collections
import re

import sys
sys.path.insert(1, '../src')
import jdata

# Some test dates
utc=datetime(2020,8,20,10,20,30)
utcoffset = round((datetime.now()-datetime.utcnow()).total_seconds())
loc=utc+timedelta(seconds=utcoffset)
unix=utc.timestamp()
#utc=datetime.now(timezone.utc)
#loc=datetime.now().replace(microsecond=0)
#unix=utc.timestamp()

# Test object creation
data={}
data["none"]=None
data["str"]="String"
data["bool"]=True
data["num"]=42
data["float"]=4.2
data["date"]={"local":loc,"utc":utc,"unix":unix}
data["list"]=["a1","a2","a3"]
data["dict"]={"x":20,"y":22}
data["complex"]=[{"var":"uno","val":1},{"var":"dos","val":2}]

# Pretty print
jdata.colprint(data, "data")

# Convertimos a json
jsonverify='{"none":null,"str":"String","bool":true,"num":42,"float":4.2,"date":{"local":"2020-08-20T12:20:30","utc":"2020-08-20T10:20:30","unix":1597911630.0},"list":["a1","a2","a3"],"dict":{"x":20,"y":22},"complex":[{"var":"uno","val":1},{"var":"dos","val":2}]}'
json=jdata.tojson(data)
if json!=jsonverify:
	print("Error converting data to json!")
	print("converted: "+json)
	print("should be: "+jsonverify)
	print
	exit(1)
jdata.colprint(json, "json")

# Convertimos otra vez a dict
data2=jdata.fromjson(json)
if data!=data2:
	print("Error converting json to data!")
	exit(1)

# Guardamos y leemos fichero json
jdata.writejson(data,"test.json", tabs=1)
data2=jdata.readjson("test.json")
if data!=data2:
	print("Error writing or reading json!")
	exit(1)

# Guardamos y leemos fichero yaml
jdata.writeyaml(data,"test.yaml")
data2=jdata.readyaml("test.yaml")
if data!=data2:
	print("Error writing or reading yaml!")
	exit(1)



#!/usr/bin/env python3

#from pydan import jdata

import sys
sys.path.append('..')
from src import jdata

ret=0

# Comprobamos reemplazo de multiples variables en un string
data={"numbers":"$n1$,$n2$,$n3$,$nx$"}
repl=jdata.replacevars(data, {"n1":"one", "n2":"two", "n3":"three", "n4":"four"})
if repl["numbers"]!="one,two,three,$nx$":
	print("ERROR reemplazando multiples variables en un mismo string")
	print(repl["numbers"])
	ret=1
else:
	print("OK: Reemplazo de multiples variables en un mismo string")

# Comprobamos reemplazo de distintos tipos de datos
data={
	"rep_str":"$str$",
	"rep_num":"$num$",
	"rep_list":"$list$",
	"rep_dict":"$dict$",
	"rep_null":"$null$",
	"rep_empty":"$empty$",
	"rep_unk":"$unk$",
	"ori_empty":"",
	"ori_null":None,
	"ori_list": [ "a", "b" ],
	"ori_dict": { "ori_a":0, "ori_b":1 },
}
repl=jdata.replacevars(data, {"str":"str", "num":1, "list":["a","b"], "dict":{"a":0,"b":1},"null":None,"empty":""})
repljson=jdata.tojson(repl)
if repljson!='{"rep_str":"str","rep_num":1,"rep_list":["a","b"],"rep_dict":{"a":0,"b":1},"rep_null":null,"rep_empty":"","rep_unk":"$unk$","ori_empty":"","ori_null":null,"ori_list":["a","b"],"ori_dict":{"ori_a":0,"ori_b":1}}':
	print("Error reemplazando distintos tipos de datos")
	jdata.colprint(data, "Original")
	jdata.colprint(repl, "Replaced")
	exit(1)
print("OK: Reemplazo de diferentes tipos de datos")

# Comprobamos borrado de variables con reemplazo a null
data={
	"rep_str":"$str$",
	"rep_num":"$num$",
	"rep_list":"$list$",
	"rep_dict":"$dict$",
	"x_rep_null":"$null$",
	"x_rep_empty":"$empty$",
	"x_rep_unk":"$unk$",
	"ori_empty":"",
	"ori_null":None,
	"ori_list": [ "a", "b" ],
	"ori_dict": { "ori_a":0, "ori_b":1 },
}
repl=jdata.replacevars(data, {"str":"str", "num":1, "list":["a","b"], "dict":{"a":0,"b":1},"null":None,"empty":""}, flags=["nullremove","emptyremove", "unkremove"])
#jdata.colprint(data, "Original")
jdata.colprint(repl, "Replaced")

exit(ret)



#!/usr/bin/env python3

from setuptools import setup

setup(
	name="pydan",
	version='2.2',
	description='Python3 Data Utils',
	author='Jose Biosca Martín',
	author_email='jbiosca@zone-sys.net',
	#url='https://zone-sys.net/',
	python_requires='>=3.6',
	#packages=["lib"],
	packages=["pydan"],
	package_dir={"pydan": "src"},
	#py_modules=['ivscript', 'jdata', 'josen', 'run']
	install_requires=[
		'setuptools',
		'setproctitle',
		'colored_traceback',
		'dicttoxml',
		'xmltodict',
#		'ruamel.yaml',
	],
	classifiers=[
		'Development Status :: 5 - Production/Stable',
		"License :: OSI Approved :: MIT License",
		#'Topic :: Software development',
	],
)
